package de.hdm_stuttgart.mi.sd1.intmax;

/**
 * Dealing with array values
 *
 */
public class Max {
	
	/**
	 * An array may contain multiple values being equal to the maximum.
	 * The sample [-4, 5, 2, 5, 4] contains two elements being equal to
	 * the array's maximum value 5. This method retrieves the first index
	 * of an array element being equal to the maximum. In the current 
	 * example the desired index is 1 pointing to the second array element.
	 * 
	 * @param values An array of arbitrary values.
	 * 
	 * @return The smallest index of an array member being equal to the maximum. 
	 * <dl>
      <dt><b>Precondition:</b></dt>
       <dd>0 &lt; values.length</dd>
      <dt><b>Postcondition:</b></dt>
       <dd>0 &lt;= return value &lt; values.length</dd>
     </dl>
	 */
  public static int getFirstMaxIndex(int[] values) {
    int
    firstMaxIndex = 0;                    // The index of the first array element being equal to the maximum value
    
    for (int i = 1; i < values.length; i++) {
      if (values[firstMaxIndex] < values[i]) {// Another value larger than the current maximum candidate
        firstMaxIndex = i;           // New index to possible first maximum value
      }
    }
    return firstMaxIndex;
  }
  
  /**
   * An array may contain multiple values being equal to the maximum.
   * The sample [-4, 5, 2, 5, 4] contains two elements being equal to
   * the array's maximum value 5. This method retrieves all index
   * values of array element being equal to the maximum and returns
   * them as an array in ascending order. In the current example the
   * returned array will contain the indices [1, 3] pointing to the
   * second and fourth array elements.
   * 
   * @param values An array of arbitrary values.
   * 
   * @return All index values in ascending order of any array member's
   * being equal to the maximum. 
   * <dl>
      <dt><b>Precondition:</b></dt>
       <dd>0 &lt; values.length</dd>
      <dt><b>Postcondition:</b></dt>
       <dd>0 &lt; length of returned array</dd>
     </dl>
   */
  public static int[] getMaxIndexValues(int[] values) {
    int 
    numberOfMaxValues = 1,                // The number of array elements being equal to the maximum.
    firstMaxIndex = 0;                    // The index of the first array element being equal to the maximum value.
    
    for (int i = 1; i < values.length; i++) {
      if (values[firstMaxIndex] == values[i]) {      // Another value being identical to the maximum?
        numberOfMaxValues++;
      } else if (values[firstMaxIndex] < values[i]) {// Even greater than the maximum?
        values[firstMaxIndex] = values[i];           // Raise the maximum candidate value
        firstMaxIndex = i;                  // New index to possible first maximum value
        numberOfMaxValues = 1;              // No luck so far, redo from Start!
      }
    }
    // Now we do know:
    // 1. The first max value's index aka firstMaxIndex
    // 2. the number of array members being equal to the array's maximum value.
    // We can this allocate an array of required size:
    //
    final int[] ascendingIndexList = new int[numberOfMaxValues];

    // .. and fill in the corresponding index values
    int ascendingArrayIndex = 0;
    // We already know the array's first element:
    ascendingIndexList[ascendingArrayIndex++] = firstMaxIndex;
    // Let's fill in the remaining index values
    //
    for (int i = firstMaxIndex + 1; i < values.length; i++) {
      if (values[firstMaxIndex] == values[i]) {
        ascendingIndexList[ascendingArrayIndex++] = i;
      }
    }
    return ascendingIndexList;
  }
}