import greenfoot.Greenfoot;
import greenfoot.World; // imports Actor, World, Greenfoot, GreenfootImage

/**
 * A crab's world of configurable size and other nifty
 * features.
 *
 */
public class CrabWorld extends World {

  private final static int // Width and height of our
      worldWidth = 700,   // crab's world.
      worldHeight = 560,

      initialLobsterCount = 3,
      initialWormCount = 10;

  /**
   * @return A random x-coordinate ranging from 0 to the worlds's width in pixel units
   *         - 1. A width of e.g. 100 sets the range to {0, 1,..., 99}.
   */
  public static int getRandomX() {
    return Greenfoot.getRandomNumber(worldWidth);
  }

  /**
   * @return A random y-ccordinate ranging from 0 to the worlds's height in pixel
   *         units - 1. A height of e.g. 70 sets the range to {0, 1,..., 69}.
   */
  public static int getRandomY() {
    return Greenfoot.getRandomNumber(worldHeight);
  }

  /**
   * @return A random rotation within the range [0, 1, ..., 360[.
   */
  public static int getRandomRotation() {
    return Greenfoot.getRandomNumber(360);
  }

  /**
   * Create the crab world (the beach). Every cell of our world is just 1 pixel.
   */
  public CrabWorld() {
    super(worldWidth, worldHeight, 1);
    populateWorld();
  }

  /**
   * Create the objects for the start of the game.
   */
  public void populateWorld() {
    addObject(new Crab(getRandomRotation()), getRandomX(), getRandomY());

    // Creating lobsters.
    for (int i = 0; i < initialLobsterCount; i++) {
      addObject(new Lobster(getRandomRotation()), getRandomX(), getRandomY());
    }
    // Creating worms.
    for (int i = 0; i < initialWormCount; i++) {
      addObject(new Worm(), getRandomX(), getRandomY());
    }
  }
}