import greenfoot.Greenfoot;
import greenfoot.World; // imports Actor, World, Greenfoot, GreenfootImage

/**
 * A crab's world of configurable size and other nifty
 * features.
 *
 */
public class CrabWorld extends World {
  
  private final static int
      worldWidth = 700,     // Width and height of
      worldHeight = 560,    // our crab's world.

      initialLobsterCount = 3,  // Start a game with these numbers
      initialWormCount = 10,    // of lobsters and worms.
      
      minimalLobsterCrabDistance = 100; // The minimal distance from our crab to
                                        // any lobster when starting the game.

  /**
   * @return A random x-coordinate ranging from 0 to the worlds's width in pixel units
   *         - 1. A width of e.g. 100 sets the range to {0, 1,..., 99}.
   */
  public static int getRandomX() {
    return Greenfoot.getRandomNumber(worldWidth);
  }

  /**
   * @return A random y-ccordinate ranging from 0 to the worlds's height in pixel
   *         units - 1. A height of e.g. 70 sets the range to {0, 1,..., 69}.
   */
  public static int getRandomY() {
    return Greenfoot.getRandomNumber(worldHeight);
  }

  /**
   * @return A random rotation within the range [0, 1, ..., 360[.
   */
  public static int getRandomRotation() {
    return Greenfoot.getRandomNumber(360);
  }

  /**
   * Create the crab world (the beach). Every cell of our world is just 1 pixel.
   */
  public CrabWorld() {
    super(worldWidth, worldHeight, 1);
    populateWorld();
  }

  /**
   * Create the objects for the start of the game.
   */
  public void populateWorld() {
    
    final int crabX = getRandomX(), // Our crab's initial (x|y) coordinates are
              crabY = getRandomY(); // needed for later calculations, see below.
    
    // Create our crab.
    addObject(new Crab(getRandomRotation()), crabX, crabY);

    // Creating lobsters.
    int numLobsters = 0;
    while (numLobsters < initialLobsterCount) { // We use a while loop instead of for since
                                                // numLobsters gets incremented condionally.
      
      final int lobsterX = getRandomX(),      // Potential lobster's position
                lobsterY = getRandomY(),      // at (lobsterX|lobsterY).
                  deltaX = lobsterX - crabX,
                  deltaY = lobsterY - crabY;
      
      // Pythagoras is talking to us. Do you listen? If you can't hear him, take a pencil
      // and a sheet of paper to sketch the problem's geometry.
      //
      // We only add a lobster at coordinate position (lobsterX|lobsterY) if
      // its distance to our crab is sufficiently large.
      //
      if (minimalLobsterCrabDistance * minimalLobsterCrabDistance <   // Distance between lobster and crab is
          deltaX * deltaX + deltaY * deltaY) {                        // larger than minimalLobsterCrabDistance.
        addObject(new Lobster(getRandomRotation()), lobsterX, lobsterY);
        numLobsters++;
      }
    }
    
    // Creating worms. Easy: No conditions apply.
    for (int i = 0; i < initialWormCount; i++) {
      addObject(new Worm(), getRandomX(), getRandomY());
    }
  }
}