package de.hdm_stuttgart.mi.sd1.fraction;

public class Fraction {

  long numerator,denominator;
  
  /**
   * @param numerator The fraction's numerator.
   * @param denominator The fraction's denominator.
   */
  public Fraction(long numerator, long denominator) {
    setNumerator(numerator);
    setDenominator(denominator);
  }
  /**
   * @return The fraction's decimal value e.g. 1/3 = 0.3333...
   */
  public double getValue(){
    return (double) numerator / denominator;
  }
  /**
   * @return The fraction's numerator       
   */
  public long getNumerator() {
    return numerator;
  }
  /**
   * @param numerator Set the fraction's numerator. 
   */
  public void setNumerator(long numerator) {
    this.numerator = numerator;
  }
  /**
   * @return
   *       The fraction's denominator value
   */
  public long getDenominator() {
    return denominator;
  }
  /**
   * 
   * @param denominator Set the fraction's denominator
   */
  public void setDenominator(long denominator) {
    this.denominator = denominator;
  }

  /**
   * Add a second fraction to the current instance.
   * 
   * @param f A second fraction.
   * 
   * @return The sum of the current instance and f according to:
   *
{@html.extend <math display="block" xmlns="http://www.w3.org/1998/Math/MathML">
  <mrow>
    <mrow>
      <mfrac>
        <mi>a</mi>
        <mi>b</mi>
      </mfrac>
      <mo>+</mo>
      <mfrac>
        <mi>x</mi>
        <mi>y</mi>
      </mfrac>
    </mrow>
    <mo>=</mo>
    <mfrac>
      <mrow>
        <mrow>
          <mi>a</mi>
          <mi>y</mi>
        </mrow>
        <mo>+</mo>
        <mrow>
          <mi>b</mi>
          <mi>x</mi>
        </mrow>
      </mrow>
      <mrow>
        <mi>b</mi>
        <mi>y</mi>
      </mrow>
    </mfrac>
  </mrow>
</math>}
   */
  public Fraction add(Fraction f) {
    return new Fraction( numerator * f.denominator + denominator * f.numerator,
        denominator * f.denominator);
  }
  /**
   * Multiply a second fraction by this instance 
   * @param f Building the product with this second fraction. 
   * @return The result of multiplying the current instance by f according to:
  {@html.extend  <math display="block" xmlns="http://www.w3.org/1998/Math/MathML">
  <mrow>
    <mrow>
      <mrow>
        <mfrac>
          <mi>a</mi>
          <mi>b</mi>
        </mfrac>
        <mfrac>
          <mi>x</mi>
          <mi>y</mi>
        </mfrac>
      </mrow>
      <mo>=</mo>
      <mfrac>
        <mrow>
          <mi>a</mi>
          <mi>x</mi>
        </mrow>
        <mrow>
          <mi>b</mi>
          <mi>y</mi>
        </mrow>
      </mfrac>
    </mrow>
  </mrow>
</math>}
  */
  public Fraction mult(Fraction f) {
    return new Fraction(numerator * f.numerator, 
        denominator * f.denominator);
  }
}
