import greenfoot.Actor;
import greenfoot.GreenfootImage;

/**
 * Implementing a single cell. Each cell has its own state information
 * and a reference to its surrounding neighbors,
 *
 */
public class Cell extends Actor {

  CellState state;
  final GreenfootImage myBody;
  final int myBodySize;

  /**
   * Create the cell body's image and initialize state.
   * 
   * @param cellSize The cell's size in pixel units,
   * @param intialState Indicating {@link CellState#living} or {@link CellState#dead} 
   */
  public Cell(int cellSize, CellState intialState) {
    super();
    state = intialState;
    myBody = new GreenfootImage(cellSize, cellSize);
    setImage(myBody);
    myBodySize = cellSize - 2;
    displayState();
  }

  /**
   * Set the state of the cell.
   * @param state See {@link #getState()}}
   */
  public void setState(final CellState state) {
    this.state = state;
    displayState();
  }

  /**
   * Get the state of the cell.
   * @return Either {@link CellState#living} or {@link CellState#dead}.
   */
  public CellState getState() {
    return state;
  }

  /**
   * Draw the cell's body based on its state.
   */
  private void displayState() {
    myBody.setColor(state.color);
    myBody.fillRect(1, 1, myBodySize, myBodySize);
  }
}
