package de.hdm_stuttgart.mi.sda1.jdom.background;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.jdom2.output.Format;
import org.jdom2.output.XMLOutputter;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

import de.hdm_stuttgart.mi.sda1.jdom.common.MySaxErrorHandler;


/**
 * Handling address book data.
 *
 */
public class TablePresentation {
	private final SAXBuilder builder = new SAXBuilder();

	/**
	 * Write errors and warnings to {@link System#err}.
	 */
	public TablePresentation() {
		builder.setErrorHandler(new MySaxErrorHandler(System.err));
	}

	/**
	 * Read XML file data and create corresponding HTML output.
	 * 
	 * @param xmlFilename The XML input file containing address book data.
	 * @throws JDOMException Internal error.
	 * @throws IOException IO related errors.
	 */
	public void process(final String xmlFilename) throws JDOMException,
			IOException {

		// Create html <table> skeleton:
	  // <table>
	  //   <tr>
	  //     <th>Name</th>
	  //     <th>Birthday</th>
	  //   </tr>
	  // </table>
		final Element table = new Element("table"),
		        trHead = new Element("tr");
		table.addContent(trHead);
		trHead.addContent(new Element("th").addContent("Name"));
		trHead.addContent(new Element("th").addContent("Birthday"));

		// Read address book from XML input file
		final Document addressbook = builder.build(xmlFilename);
		// Search for <person> elements
		@SuppressWarnings({ "unchecked", "rawtypes" })
		final XPathExpression<Element> xpath = (XPathExpression<Element>) (XPathExpression) XPathFactory
				.instance().compile("/addressbook/person");
		final List<Element> persons = xpath.evaluate(addressbook);
		
		// Now append a <tr> for each <person> input element:
    // <table>
		// ... table's column head entries, see above
    //   <tr>
    //     <td>Scott Geoffrey</td>
    //     <td>1942-07-22</td>
    //   </tr>
		//   <tr>...</tr> ...
    // </table>
    boolean setBackground = true; // keep track of table row background state.

		for (final Element person : persons) {
			final Element tr = new Element("tr");
	    if (setBackground) {
	      tr.setAttribute("style", "background-color: #FFFF88;");
	    } 
	    setBackground = !setBackground;
	    table.addContent(tr);
			tr.addContent(new Element("td").addContent(person.getChild("name").getText()));
			tr.addContent(new Element("td").addContent(person.getChild("birthday").getText()));
		}

		// Serialize the <html> tree to standard output.
		final Format outFormat = Format.getPrettyFormat();
		final XMLOutputter printer = new XMLOutputter(outFormat);
		printer.output(table, System.out);
	}
}