package de.hdm_stuttgart.mi.sda1.usercolumns;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.jdom2.output.Format;
import org.jdom2.output.XMLOutputter;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

import de.hdm_stuttgart.mi.sda1.jdom.common.MySaxErrorHandler;

/**
 * Address book data.
 *
 */
public class TablePresentation {
	private final SAXBuilder builder = new SAXBuilder();

	/**
	 * 
	 */
	public TablePresentation() {
		builder.setErrorHandler(new MySaxErrorHandler(System.err));
	}
  /**
   * Reading XML input an create corresponding HTML output
   * @param xmlFilename XML file input data
   * @throws JDOMException Internal errors
   * @throws IOException IO related errors.
   */
	public void process(final String xmlFilename) throws JDOMException,
			IOException {

		// Read address book from XML input file
		final Document addressbook = builder.build(xmlFilename);

		// Create HTML <table/>
		final Element table = new Element("table");

		// Search for <person> elements
		@SuppressWarnings({ "unchecked", "rawtypes" })
		final XPathExpression<Element> xpath = (XPathExpression<Element>) (XPathExpression) XPathFactory
				.instance().compile("/addressbook/person");
		final List<Element> persons = xpath.evaluate(addressbook);
		
		// Create the <tr> row of names.
		final Element nameRow = new Element("tr");
		table.addContent(nameRow);
		nameRow.addContent(new Element("th").addContent("Name"));

		// Create the <tr> row of birthdays.
		final Element birthdayRow = new Element("tr");
		table.addContent(birthdayRow);
		birthdayRow.addContent(new Element("th").addContent("Birthday"));

		for (Element person : persons) {
			nameRow.addContent(new Element("td").addContent(person.getChild("name").getText()));
			birthdayRow.addContent(new Element("td").addContent(person.getChild("birthday").getText()));
		}
		// Serialize the <html> tree to standard output.
		final Format outFormat = Format.getPrettyFormat();
		final XMLOutputter printer = new XMLOutputter(outFormat);
		printer.output(table, System.out);
	}
}