package de.hdm_stuttgart.mi.sda1.saxhtml;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Turning &lt;memo&gt; documents to HTML
 *
 */
public class Memo2HtmlHandler extends DefaultHandler {

  boolean printElementContent = false;

  @Override public void startDocument() throws SAXException {
    // Create HTML head
    print("<html xmlns='http://www.w3.org/1999/xhtml'>\n" 
        + "  <head><title>A Memo</title></head>\n"
        + "  <body>\n"); // <from> content follows ...
  }

  @Override
  public void startElement(String uri, String localName, String tagName,
      Attributes attributes) throws SAXException {
    switch(tagName) {
    case "from": 
      print("    <dl>\n"
        +   "      <dt>Sender:</dt>\n"
        +   "      <dd>");
      printElementContent = true;
    break;
    
    case "to":
      print("          <li>");
      printElementContent = true;
    break;
    
    case "subject":
    case "content":
    case "memo":
      break;

    default:
      print("unexpected element '" + tagName + "'");
    }
  }

  @Override
  public void characters(char[] ch, int start, int length) throws SAXException {
    if (printElementContent) {
      print(new String(ch, start, length).trim());
    }
  }
  
  @Override
  public void endElement(String uri, String localName, String tagName)
      throws SAXException {
    switch(tagName) {
    
    case "from":
      print("</dd>\n"
        +   "      <dt>Recipients:</dt>\n"
        +   "      <dd>\n" 
        +   "        <ul>\n");
      printElementContent = false;
    break;
    
    case "to":
      print("</li>\n");
      printElementContent = false;
    break;
    
    case "subject":
      print("        </ul>\n" // Ending list of recipients
        +   "      </dd>\n"
        +   "    </dl>\n");
      break;
    }
  }

  @Override public void endDocument() throws SAXException {
    print("  </body>\n"
        + "</html>\n"); 
  }

  // Shortcut System.out.print
  private void print(final String s) { System.out.print(s);}
}