package de.hdm_stuttgart.mi.sda1.saxhtml;

import java.util.List;
import java.util.Vector;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Turning &lt;memo&gt; documents to HTML
 *
 */
public class Memo2HtmlHandler extends DefaultHandler {

  String subject, sender;
  final List<String> recipients= new Vector<String>();
  final StringBuffer buffer = new StringBuffer();
  
  @Override public void startDocument() throws SAXException {
    // Clear
    recipients.clear();
    
    // Create HTML head
    print("<html xmlns='http://www.w3.org/1999/xhtml'>\n" 
        + "  <head><title>A Memo</title></head>\n"
        + "  <body>\n"); // <from> content follows ...
  }
  
  @Override
  public void startElement(String uri, String localName, String tagName,
      Attributes attributes) throws SAXException {
      buffer.setLength(0);
  }

  @Override
  public void characters(char[] ch, int start, int length) throws SAXException {
    buffer.append(ch, start, length);
  }
  
  @Override
  public void endElement(String uri, String localName, String tagName)
      throws SAXException {
    switch(tagName) {
    
    case "from":
      sender = buffer.toString();
    break;
    
    case "to":
      recipients.add(buffer.toString());
      break;
    
    case "subject":
      subject = buffer.toString();
      break;
    }
  }

  @Override public void endDocument() throws SAXException {
    
  print(  "    <h2>Subject:" + subject + "</h2>\n"
      +   "    <dl>\n"
      +   "      <dt>Sender:</dt>\n"
      +   "      <dd>" + sender + "</dd>\n"
      +   "      <dt>Recipients:</dt>\n"
      +   "      <dd>\n" 
      +   "        <ul>\n");

  for(final String recipient: recipients) {
    print("          <li>" + recipient + "</li>\n");
  }
  print  ("        </ul>\n"
      +   "      </dd>\n"
      +   "    </dl>\n"
      +   "  </body>\n"
      +   "</html>\n"); 
  }

  // Shortcut System.out.print
  private void print(final String s) { System.out.print(s);}
}