package de.hdm_stuttgart.mi.sda2.forum;

import java.io.Serializable;
import java.sql.SQLException;

import javax.persistence.EntityManager;

import com.vaadin.data.Property.ValueChangeListener;
import com.vaadin.data.fieldgroup.FieldGroup.CommitException;
import com.vaadin.navigator.Navigator;
import com.vaadin.navigator.View;
import com.vaadin.navigator.ViewChangeListener.ViewChangeEvent;
import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Button.ClickListener;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.PasswordField;
import com.vaadin.ui.VerticalLayout;

import de.hdm_stuttgart.mi.sda2.forum.domain.User;
import de.hdm_stuttgart.mi.sda2.forum.tools.HashProvider;
import de.hdm_stuttgart.mi.sda2.forum.tools.MyBeanFieldGroup;
import de.hdm_stuttgart.mi.sda2.forum.tools.PersistenceHelper;
import de.hdm_stuttgart.mi.sda2.forum.tools.ValidateGlobal;
import de.hdm_stuttgart.mi.sda2.forum.tools.ValidateSecondIdenticalInput;

public class Register extends CustomComponent implements View, ValidateGlobal {

	private static final long serialVersionUID = -1309958813377546099L;
	public final static String viewId = Register.class.getCanonicalName();

	private transient EntityManager em = PersistenceHelper.getEntityManager();
	
	final Button cancelButton = new Button("Cancel"), okButton = new Button(
			"OK");

	// The backing Pojo
	final User user = new User();

	// The Pojo's editor form
	final MyBeanFieldGroup<User> userForm = new MyBeanFieldGroup<User>(
			User.class, this);

	// Password has to be entered twice for consistency check
	final PasswordField password1Field, password2Field = new PasswordField(
			"Repeat Pw.");

	/**
	 * Create a registration instance allowing to navigate to other views.
	 * 
	 * @param navigator
	 * @throws SQLException
	 */
	public Register(Navigator navigator) {

		final VerticalLayout mainLayout = new VerticalLayout();
		setCompositionRoot(mainLayout);
		mainLayout.addComponents(userForm.buildAndBind("Name", "name"));
		mainLayout.addComponents(userForm.buildAndBind("Email", "email"));

		password1Field = // We need to compare both password entries for
							// equality later
		userForm.buildAndBind("Password", "password", PasswordField.class);
		mainLayout.addComponents(password1Field);

		password2Field.addValidator(new ValidateSecondIdenticalInput(
				password1Field));
		password1Field.addValidator(new ValidateSecondIdenticalInput(
				password2Field));
		mainLayout.addComponents(password2Field);

		{// Preparing cancel/OK buttons
			final HorizontalLayout buttonLayout = new HorizontalLayout();
			buttonLayout.addComponent(cancelButton);
			buttonLayout.addComponent(okButton);
			okButton.setEnabled(false); // Wait until sensible data has been
										// entered

			mainLayout.addComponent(buttonLayout);
		}
		cancelButton.addClickListener(new ClickListener() {
			private static final long serialVersionUID = -2794080599262943594L;

			@Override
			public void buttonClick(ClickEvent event) {
				navigator.navigateTo(MyLogin.viewId);
			}
		});

		okButton.addClickListener(new ClickListener() {
			private static final long serialVersionUID = 3427398691509635900L;

			@Override
			public void buttonClick(ClickEvent event) {
				try {
					userForm.commit();
					final String passwordHash =
							HashProvider.getSaltedHash(user.getPassword().toCharArray());
					user.setPassword(passwordHash);
					
					em.getTransaction().begin();
					em.persist(user);
					em.getTransaction().commit();
					em.detach(user);
					user.setId(null);

					System.out.println("committed");
					// dbConnection.close();
					navigator.navigateTo(MyLogin.viewId);

				} catch (CommitException e) {
					System.err.println("commit failed for unknown reason");
					e.printStackTrace();
				}
			}
		});

		
		password2Field.addValueChangeListener((ValueChangeListener & Serializable) event -> {
			userForm.setValidationVisibility(true);
			password2Field.setValidationVisible(true);
			validateGlobal();
		});
		
		userForm.setBuffered(true);
	}

	public void validateGlobal() {
		if (userForm.isValid() && password2Field.isValid()) {
			okButton.setEnabled(true);
		} else {
			okButton.setEnabled(false);
		}
	}

	@Override
	public void enter(ViewChangeEvent event) {
		user.setEmail(null);
		user.setPassword(null);
		user.setName(null);
		userForm.setItemDataSource(user);
		password2Field.setValue("");
		password2Field.setValidationVisible(false);
		userForm.setValidationVisibility(false);
	}
}
