package component.emails.list;

import java.util.List;
import java.util.Vector;

import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OrderColumn;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

/**
 * @author goik
 * 
 *         {@link User} instances with addresses
 * 
 */
@Entity
@Table(uniqueConstraints={@UniqueConstraint(columnNames={"uid"}),
    @UniqueConstraint(columnNames={"uidNumber"})})
public class User {

  private Long id;
  @Id
  @GeneratedValue
  public Long getId() {return id;}
  protected void setId(Long id) {this.id = id;}

  int uidNumber;
  public int getUidNumber() {return uidNumber;}
  public void setUidNumber(int uidNumber) {this.uidNumber = uidNumber;}

  String uid;

  /**
   * 
   * @return The user's unique login name e.g. "goik"
   */
  @Column(nullable=false)
  public String getUid() {return uid;}
  public void setUid(String uid) {this.uid = uid;}

  String cname;
  /**
   * @return The user's common name e.g. "Martin Goik"
   */
  @Column(nullable = false)
  public String getCname() {return cname;}
  public void setCname(String cname) {this.cname = cname;}

  private List<Email> emails = new Vector<Email>();
  @ElementCollection
  @OrderColumn
  public  List<Email> getEmails() { return emails; }
  public void setEmails(List<Email> emails) { this.emails = emails;}
  
  protected User() {}

  /**
   * @param uidNumber See {@link #getUidNumber()}.
   * @param uid See {@link #getUid()}. This parameter must not be null
   * @param cname See {@link #getCname()}.
   */
  public User(final int uidNumber, final String uid, final String cname) {
    setUidNumber(uidNumber);
    setUid(uid);
    setCname(cname);
  }
  @Override
  public boolean equals(Object other) {
    if (this == other) {
      return true;
    } else if (other instanceof User) {
      return this.getUid().equals(((User) other).getUid());
    } else {
      return false;
    }
  }
  @Override
  public int hashCode() {
    if (null == getUid()) {
      return System.identityHashCode(this);
    } else {
      return getUid().hashCode();
    }
  }
}