package entity.company8.model;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import org.hibernate.annotations.Cascade;

/**
 * 
 *         {@link Employee} and {@link Project} related by
 *         {@link EmployeeProject} and {@link OneToMany} / {@link ManyToOne}
 * 
 */
@Entity
@Table(uniqueConstraints={@UniqueConstraint(columnNames={"no"})})
public class Project {

   @Id
   @GeneratedValue
   public Long getId() {return id;}
   protected void setId(Long id) {this.id = id;}
   private Long id;

   public int getNo() { return no;}
   public void setNo(int no) { this.no = no;}
   int no;

   public String getTitle() { return title;}
   public void setTitle(String title) { this.title = title;}
   String title;


   @OneToMany(orphanRemoval=true, fetch = FetchType.LAZY, mappedBy ="pk.project",
         cascade = {CascadeType.PERSIST, CascadeType.MERGE})
   @Cascade({org.hibernate.annotations.CascadeType.SAVE_UPDATE})
   public Set<EmployeeProject> getEmployeeProjects() { return employeeProjects;}
   public void setEmployeeProjects(Set<EmployeeProject> employeeProjects) { this.employeeProjects = employeeProjects;}
   private Set<EmployeeProject> employeeProjects = new HashSet<EmployeeProject>();

   public void addEmployee(final Employee employee) {
      EmployeeProject ep = new EmployeeProject();
      ep.setEmployee(employee);
      ep.setProject(this);
      getEmployeeProjects().add(ep);
      employee.getEmployeeProjects().add(ep);
   }

   public void removeEmployee(final Employee employee) {
      
      Set<EmployeeProject> eps = getEmployeeProjects();
      
      for (EmployeeProject ep: eps) {
         if (ep.getEmployee().equals(employee)){
            getEmployeeProjects().remove(ep);
            employee.getEmployeeProjects().remove(ep);
            return;
         }
      }
      
      EmployeeProject ep = new EmployeeProject();
      ep.setEmployee(employee);
      ep.setProject(this);
      getEmployeeProjects().add(ep);
      employee.getEmployeeProjects().add(ep);
   }

   protected Project(){}

   public Project(final int no, final String title) {
      setNo(no);
      setTitle(title);
   }
   @Override
   public boolean equals(Object other) {
      if (this == other) {
         return true;
      } else if (other instanceof Project) {
         return getNo() == ((Project) other).getNo();
      } else {
         return false;
      }
   }
   @Override
   public int hashCode() { return getNo();}
}