package hibintro.v7;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import org.hibernate.annotations.Index;

/**
 * @author goik
 * 
 *         {@link User} instances with a non-unique index
 *         on {@link #getCname()} property for faster database retrieval.
 * 
 */
@Entity
@Table(uniqueConstraints={@UniqueConstraint(columnNames={"uid"})})
@org.hibernate.annotations.Table(appliesTo="User",
                          indexes = {@Index(name = "findCname", columnNames = {"cname"})})
public class User {

  int uidNumber;
  @Id
  public int getUidNumber() {
    return uidNumber;
  }
  public void setUidNumber(int uidNumber) {
    this.uidNumber = uidNumber;
  }

  String uid;

  /**
   * 
   * @return The user's unique login name e.g. "goik"
   */
  @Column(nullable=false)
  public String getUid() {
    return uid;
  }

  /**
   * @param uid
   *          See {@link #getUid()}.
   */
  public void setUid(String uid) {
    this.uid = uid;
  }

  String cname;

  /**
   * @return The user's common name e.g. "Martin Goik"
   */
  @Column(nullable = false)
  public String getCname() {
    return cname;
  }

  /**
   * @param cname
   *          See {@link #getCname()}.
   */
  public void setCname(String cname) {
    this.cname = cname;
  }

  /**
   * Hibernate/JPA require a default constructor
   */
  public User() {
  }

  /**
   * @param uidNumber See {@link #getUidNumber()}.
   * @param uid See {@link #getUid()}.
   * @param cname See {@link #getCname()}.
   */
  public User(int uidNumber, String uid, String cname) {
    setUidNumber(uidNumber);
    setUid(uid);
    setCname(cname);
  }
}