package de.hdm_stuttgart.de.sd1.taglet;

import java.util.Map;

import com.sun.javadoc.Tag;
import com.sun.tools.doclets.Taglet;

public class HtmlExtensionTaglet implements Taglet {
  
  private static final String NAME = "html.extend";

  /**
   * @return  the name of this custom tag.
   */
  public String getName() {
      return NAME;
  }

  /**
   * @return true since this tag can be used in a field
   *         doc comment
   */
  public boolean inField() {
      return true;
  }

  /**
   * @return true since this tag can be used in a constructor
   *         doc comment
   */
  public boolean inConstructor() {
      return true;
  }

  /**
   * @return true since this tag can be used in a method
   *         doc comment
   */
  public boolean inMethod() {
      return true;
  }

  /**
   * @return true since this tag can be used in an overview
   *         doc comment
   */
  public boolean inOverview() {
      return true;
  }

  /**
   * @return true since this tag can be used in a package
   *         doc comment
   */
  public boolean inPackage() {
      return true;
  }

  /**
   * @return true since this
   */
  public boolean inType() {
      return true;
  }

  /**
   * Will return true since this is an inline tag.
   * @return true since this is an inline tag.
   */

  public boolean isInlineTag() {
      return true;
  }

  /**
   * Register this Taglet.
   * @param tagletMap  the map to register this tag to.
   */
  public static void register(Map<String, Taglet> tagletMap) {
     final HtmlExtensionTaglet tag = new HtmlExtensionTaglet();
     if (null != tagletMap.get(tag.getName())) {
         tagletMap.remove(tag.getName());
     }
     tagletMap.put(tag.getName(), tag);
  }

  /**
   * Given the <code>Tag</code> representation of this custom
   * tag, return its string representation.
   * @param tag he <code>Tag</code> representation of this custom tag.
   * 
   * @return The tag's textual string.
   */
  public String toString(Tag tag) {
      return tag.text();
  }

  /**
   * This method should not be called since arrays of inline tags do not
   * exist.  Method {@link #toString(Tag)} should be used to convert this
   * inline tag to a string.
   * @param tags the array of <code>Tag</code>s representing of this custom tag.
   */
  public String toString(Tag[] tags) {
      return null;
  }
  
}
