package dom;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;

/** 
 * Traversing a document instance by pure DOM method calls.
 * @author goik
 */
public class ArticleOrder {

   // Though we are playing DOM here, a SAX parser still
   // assembles our DOM tree.
   private final SAXBuilder builder = new SAXBuilder();
   
   public ArticleOrder() {
      // Though an ErrorHandler is not strictly required it allows
      // for easier localization of XML document errors
      builder.setErrorHandler(new MySaxErrorHandler(System.out));
   }

   /** Descending a catalog till its &lt;item&gt; elements. For each product
    *  its name and order number are being written to the output.
    * @param filename .
    * @throws JDOMException General parsing fault
    * @throws IOException file access problem
    */
   public void process(final String filename) throws JDOMException, IOException {
      
      // Parsing our XML file
      final Document docInput = builder.build(filename);
      
      // Accessing the document's root element
      final Element docRoot = docInput.getRootElement();
      
      // Accessing the <item> children of parent element <catalog>
      final List<Element> items = docRoot.getChildren("item"); // This method only selects Element nodes

      final Element titel = docRoot.getChild("titel");
      System.out.println("Katalogtitel: " + titel.getText());
      for (final Element item : items) {
         System.out.println("Article: " + item.getText()
       + ", order number: " + item.getAttributeValue("orderNo"));
      }
   }
}
















