package sax.context;

import java.util.HashSet;
import java.util.Set;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;

/** Reading attributes from element events */
public class ImportHandler implements ContentHandler {

  private Set<String> currentDescriptions = new HashSet<String>();
  String lastCharacterUnit = null
      ,lastAgeString = null
      ,currentProductId;
  @Override
  public void startElement(String uri, String localName, String qName,
      Attributes attributes) throws SAXException {
    switch(qName) {
    case "product":
      currentProductId = attributes.getValue("id");
      System.out.print("INSERT INTO Product VALUES ('" + currentProductId + "'");
    }
  }

  @Override
  public void endElement(final String uri, final String localName, final String qName)
      throws SAXException {
    switch(qName) {
    case "product":
      if (null == lastAgeString) {
        System.out.print( ", NULL");
      } else {
        try {
          System.out.print(", " + Integer.parseInt(lastCharacterUnit));
        } catch (NumberFormatException ex) {
          System.err.println("Age is not an integer value:" + lastCharacterUnit);
        }
        lastAgeString = null;
      }
      
      System.out.println(");");
      flushDescriptionEntries();
      break;
    case "name":
      System.out.print(", '" + lastCharacterUnit + "'");
    break;
    
    case "description":
      // Do not interfere with the current INSERT INTO Product ... 
      // statement. Instead postpone related INSERT INTO Description ...
      // operations, see flushDescriptionEntries().
      currentDescriptions.add(lastCharacterUnit);
      break;
    case "age":
      lastAgeString = lastCharacterUnit;
      break;
    }
  }
  private void flushDescriptionEntries() {
    // Add <description> related INSERTs
    for (final String description: currentDescriptions) {
      System.out.println("INSERT INTO Description VALUES('" +
         currentProductId + "', '" + description + "');");
    }
    // Next <product> is yet to come, so
    // clear the current set of descriptions.
    currentDescriptions.clear();
  }

  @Override
  public void characters(final char[] ch, final int start, final int length)
      throws SAXException {
    lastCharacterUnit = new String(ch, start,length);
  }

  // We don't need these remaining callbacks 

  @Override public void setDocumentLocator(Locator locator) {}
  @Override public void startDocument() throws SAXException {}
  @Override public void endDocument() throws SAXException {}
  @Override public void startPrefixMapping(String prefix, String uri)
      throws SAXException {}
  @Override public void endPrefixMapping(String prefix)
      throws SAXException {}
  @Override public void ignorableWhitespace(char[] ch, int start, int length)
      throws SAXException {}

  @Override public void processingInstruction(String target, String data)
      throws SAXException {}

  @Override public void skippedEntity(String name) throws SAXException {}
}