package sax.ns.stat;

import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.apache.xml.resolver.CatalogManager;
import org.apache.xml.resolver.tools.CatalogResolver;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

import dom.MySaxErrorHandler;

/** Parsing catalog instances for import to RDBMS. */
public class ElementFrequency {
  
  /** Set up a validating parser instance.
   * 
   * @throws SAXException Parsing may fail.
   * @throws ParserConfigurationException Unable to instantiate parser.
   */
  public ElementFrequency()
  
   throws SAXException, ParserConfigurationException {
      
      final SAXParserFactory saxPf = SAXParserFactory.newInstance();
      final SAXParser saxParser = saxPf.newSAXParser();
      xmlReader = saxParser.getXMLReader();

      // Set up resolving PUBLIC identifier
      final CatalogManager cm = new CatalogManager("CatalogManager.properties");
      final CatalogResolver resolver = new CatalogResolver(cm);
      xmlReader.setEntityResolver(resolver);

      xmlReader.setFeature("http://xml.org/sax/features/validation", false);
      xmlReader.setFeature("http://xml.org/sax/features/namespaces", true);
      xmlReader.setFeature("http://xml.org/sax/features/namespace-prefixes", true);
      xmlReader.setContentHandler(frequencyGatherer);
      xmlReader.setErrorHandler(new MySaxErrorHandler(System.out));
  }
  /** Initiate parsing
   * @param uri The resource to be parsed
   * @throws IOException Access related problems
   * @throws SAXException Parsing may fail
   */
  public void parse(final String uri) 
    throws IOException, SAXException {
    xmlReader.parse(uri);
  }
  /**
   * See {@link FrequencyGatherer#printStatistics()}
   */
  public void printStatistics () {
    frequencyGatherer.printStatistics();
  }
  final FrequencyGatherer frequencyGatherer = new FrequencyGatherer();
  private final XMLReader xmlReader;
  
}