package sax.ns.stat;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * This container is intended to collect all raw element names belonging to one
 * particular namespace along with their corresponding frequencies in a given
 * XML document instance.
 * 
 * A valid XHTML document instance will for example contain at least the elements
 * html, head and body having a frequency of 1. Other XHTML elements like h1 may have
 * arbitrary integer frequencies.
 * 
 * Instances of this class will appear as {@link Map} values in
 * {@link FrequencyGatherer} corresponding to a given namespace key value.
 * 
 */
@SuppressWarnings("serial")
public class ElementcountByName extends HashMap<String, Integer> implements Map<String, Integer> {
 
  /**
   * Each time a given element &lt;xyz&gt; appears in the document instance
   * its count is being incremented by one.
   * 
   * @param elementName The value "xyz" corresponding to the example above
   */
  public void increment (final String elementName) {
    final Integer current = get(elementName);
    if (null == current) { // Already present in the current map?
      put(elementName, 1); // Not yet present, adding a new entry having count 1
    } else {
      put(elementName, current + 1); // Increment count of existing entry
    }
  }

  /**
   * Print element names along wit their frequencies to standard output.
   */
  public void printStatistics() {
    for (final Entry<String, Integer> elementTags: entrySet()) {
      final int count = elementTags.getValue();
      System.out.println("<" + elementTags.getKey() + "> (" + count + 
          (1 == count? " occurrence)":" occurrences)"));
    }
  }
}