package sda.jdbc.intro;


import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * A "getting started" example to insert data into a table by
 * using JDBC. No error handling whatsoever is being supplied! 
 * 
 * @author goik
 */
public class SimpleInsert {

   /**
    * User credentials (name and password) are supplied within code. This is
    * absolutely uuuuuuugly! For a Java property based solution
    * see {@link sda.jdbc.intro.v1.SimpleInsert}.  
    * 
    * @param args unused
    * @throws SQLException possible causes:
    * <ul>
    *   <li>Driver matching JDBC URL unavailable</li>
    *   <li>No network access to database server</li>
    *   <li>Invalid credentials</li>
    *   <li>Database table 'Person' does not exist</li>
    *   <li>duplicate email (UNIQUE key)</li>
    *   <li>... something forgotten?</li>
    * </ul>
    */
   public static void main(String[] args) throws SQLException {
      
      // Step 1: Open a connection to the database server
      final Connection conn = DriverManager.getConnection (
            "jdbc:mysql://localhost:3306/hdm",  //JDBC URL
            "hdmuser",                          // Username
            "XYZ");                             // Password
      
      // Step 2: Create a Statement instance
      final Statement stmt = conn.createStatement();
      
      // Step 3: Execute the desired INSERT
      final int updateCount = stmt.executeUpdate(
               "INSERT INTO Person VALUES('Jim', 'jim@foo.org')");
      
      // Step 4: Give feedback to the enduser
      System.out.println("Successfully inserted " + updateCount + " dataset(s)");
   }
}