package sda.jdbc.intro;


import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import sda.jdbc.intro.v1.DbProps;

/**
 * A "getting started" example to read data from a table by
 * using JDBC. No error handling whatsoever is being supplied! 
 * 
 * @author goik
 */
public class SimpleRead {

   /**
    * @param args unused
    * @throws SQLException possible causes:
    * <ul>
    *   <li>Driver matching JDBC URL unavailable</li>
    *   <li>No network access to database server</li>
    *   <li>Invalid credentials</li>
    *   <li>Database table 'Person' does not exist</li>
    *   <li>... something forgotten?</li>
    * </ul>
    */
   public static void main(String[] args) throws SQLException {
      
      // Step 1: Open a connection to the database server
      final Connection conn = DriverManager.getConnection (
            DbProps.getString("PersistenceHandler.jdbcUrl"),  
            DbProps.getString("PersistenceHandler.username"),
            DbProps.getString("PersistenceHandler.password"));
      
      // Step 2: Create a Statement instance
      final Statement stmt = conn.createStatement();
      
      // Step 3: Creating the client side JDBC container holding our data records
      final ResultSet data = stmt.executeQuery("SELECT * FROM Friends");
      
      // Step 4: Dataset iteration
      while (data.next()) {
         System.out.println(data.getInt("id")
                   + ", " + data.getString("nickname")
                   + ", " + data.getString("birthdate"));
      }
   }
}