package sda.jdbc.intro.v1.prepare;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

import org.testng.Assert;
import org.testng.annotations.Test;

import sda.jdbc.intro.v1.DbProps;

public class PersistenceHandlerTest {

   final PersistenceHandler ph = new PersistenceHandler();

   @Test (groups = "connection")
   public void openCloseConnection() {
      try {
         initDatabase();
      } catch (SQLException e) {
         Assert.fail("Unable to clean up database:" + e.getLocalizedMessage());
         return;
      }
      // Initially we should be in disconnected state
      assert(!ph.isConnected());
      
      // Connecting
      assert(ph.connect());
      assert(ph.isConnected());
      
      // Disconnecting
      assert(ph.disconnect());
      assert(!ph.isConnected());
   }

   @Test (dependsOnGroups = "connection")
   public void oneDataset() {
      try {
         cleanDatabase();
      } catch (SQLException e) {
         Assert.fail("Unable to clean up database:" + e.getLocalizedMessage());
         return;
      }
      ph.connect();
      assert(ph.add("Anton", "a@mail.com"));

      // Failure expected due to primary key constraint violation
      assert(!ph.add("Anton", "a@mail.com"));
      assert(ph.getErrorMessage().equals(
            "Unable to insert 'Anton, a@mail.com': 'Duplicate entry 'a@mail.com' for key 'email''"));
      System.out.println(ph.getErrorMessage());
   }

   private void initDatabase() throws SQLException {
      
      final Connection conn = DriverManager.getConnection(
            DbProps.getString("PersistenceHandler.jdbcUrl"),
            DbProps.getString("PersistenceHandler.username"),
            DbProps.getString("PersistenceHandler.password"));
      final Statement stmt = conn.createStatement();
      stmt.executeUpdate("DROP TABLE IF EXISTS Person");
      stmt.executeUpdate("CREATE TABLE Person (\n" +
                            "name char(80)\n" + 
                            ",email CHAR(20) UNIQUE\n" +
                            ");");
      conn.close();
   }
   private void cleanDatabase() throws SQLException {
      
      final Connection conn = DriverManager.getConnection(
            DbProps.getString("PersistenceHandler.jdbcUrl"),
            DbProps.getString("PersistenceHandler.username"),
            DbProps.getString("PersistenceHandler.password"));
      final Statement stmt = conn.createStatement();
      stmt.executeUpdate("DELETE FROM Person");
      conn.close();
   }
}
