package solve.dom;

import java.io.IOException;
import java.io.PrintStream;
import java.util.List;

import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;

import dom.MySaxErrorHandler;

/**
 * This class may be used for transforming XML sources directly to
 * HTML by using {@link solve.dom.HtmlTree}. 
 *
 * @author goik
 */

public class Article2Html {
   
  private final SAXBuilder builder = new SAXBuilder();
  private final HtmlTree htmlResult;

  /**
   * Instances of this class allow to read an XML catalog and delegate the
   * transformation to HTML to a {@link HtmlTree} object,
   * see {@link #process(String, PrintStream)}. 
   */
  public Article2Html() {
    
     builder.setErrorHandler(new MySaxErrorHandler(System.out));
    
     htmlResult = new HtmlTree("Available articles", new String[] {
        "Article Description", "Order Number" });
  }

  /** Read an Xml catalog instance and insert product names among with their
   * order numbers into the HTML DOM. Then serialize HTML tree to a stream. 
   * 
   * @param 
   *   filename of the Xml source.
   * @param out
   *    The output stream for HTML serialization. 
   * @throws IOException In case filename cannot be opened
   * @throws JDOMException Parseing error
   * 
   */
  public void process(final String filename, final PrintStream out) throws JDOMException, IOException{
    final List<Element> items = 
      builder.build(filename).getRootElement().getChildren();
    
    for (final Element item : items) {
       htmlResult.appendItem(item.getText(), item.getAttributeValue("orderNo"));
    }
    htmlResult.serialize(out);
  }
}